pub struct AnyConstraintId { /* private fields */ }Expand description
A constraint id of any kind, for listing and removing constraints.
Implementations
Sourceimpl AnyConstraintId
impl AnyConstraintId
Sourcepub fn kind(self) -> ConstraintType
pub fn kind(self) -> ConstraintType
The kind of constraint the id names.
Sourcepub fn downcast<K: ConstraintKind>(self) -> Option<ConstraintId<K>>
pub fn downcast<K: ConstraintKind>(self) -> Option<ConstraintId<K>>
The typed id, if the constraint is of kind K.