pub struct VehicleTransmissionSettings { /* private fields */ }Expand description
The automatic transmission of a vehicle (Jolt VehicleTransmissionSettings in
ETransmissionMode::Auto; the manual mode is not offered). The defaults are Jolt’s wheeled
vehicle defaults;
TrackedVehicleSettings::default_transmission
gives the tracked ones.
Implementations
Sourceimpl VehicleTransmissionSettings
impl VehicleTransmissionSettings
Sourcepub fn gear_ratios(self, value: Vec<f32>) -> Self
pub fn gear_ratios(self, value: Vec<f32>) -> Self
Engine to gearbox rotation ratios of the forward gears, first gear first; at least one,
each positive. Default [2.66, 1.78, 1.3, 1.0, 0.74].
Sourcepub fn reverse_gear_ratios(self, value: Vec<f32>) -> Self
pub fn reverse_gear_ratios(self, value: Vec<f32>) -> Self
Ratios of the reverse gears; at least one, each negative. Default [-2.9].
Sourcepub fn switch_time(self, value: f32) -> Self
pub fn switch_time(self, value: f32) -> Self
Seconds a gear switch takes, not negative. Default 0.5.
Sourcepub fn clutch_release_time(self, value: f32) -> Self
pub fn clutch_release_time(self, value: f32) -> Self
Seconds the clutch takes to engage fully after a switch, not negative. Default 0.3.
Sourcepub fn switch_latency(self, value: f32) -> Self
pub fn switch_latency(self, value: f32) -> Self
Seconds to wait after the clutch engaged before another switch, not negative. Default 0.5.
Sourcepub fn shift_up_rpm(self, value: f32) -> Self
pub fn shift_up_rpm(self, value: f32) -> Self
Engine rpm above which the transmission shifts up; above the shift down rpm and below the engine’s max rpm. Default 4000.
Sourcepub fn shift_down_rpm(self, value: f32) -> Self
pub fn shift_down_rpm(self, value: f32) -> Self
Engine rpm below which the transmission shifts down, positive. Default 2000.
Sourcepub fn clutch_strength(self, value: f32) -> Self
pub fn clutch_strength(self, value: f32) -> Self
Strength of the fully engaged clutch, kg·m²/s, positive. Default 10.